#!/usr/bin/perl -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/storage
# $Id: label.pl,v 1.11 2001/10/16 17:19:16 pbaltz Exp $
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
# 
# handle changing the label information
# just uses symlinks to allow changing the label after sites have
# been put on the disk

use CCE;
use Storage qw(storage_label_link);
use Sauce::Util;

my $DEBUG = 0;

my $cce = new CCE('Domain' => 'base-storage');
$cce->connectfd();

my $disk = $cce->event_object();
my $old_disk = $cce->event_old();

if ($cce->event_is_destroy())
{
    $disk = $old_disk;
}

# just pass over internal disks
if ($disk->{internal})
{
    $cce->bye('SUCCESS');
    exit(0);
}

# label must be unique
if ($disk->{label} &&
    scalar($cce->find('Disk', { 'label' => $disk->{label} })) > 1)
{
    $cce->bye('FAIL', 'labelInUse', { 'label' => $disk->{label} });
    exit(1);
}

my $old_link = storage_label_link($old_disk->{label});
my $new_link = storage_label_link($disk->{label});

$DEBUG && warn("old link: $old_link");
$DEBUG && warn("new link: $new_link");

# always remove the old symlink
if (-l $old_link)
{
    unlink($old_link);
    Sauce::Util::addrollbackcommand("umask 000; /bin/ln -sf $disk->{mountPoint} \"$old_link\"");
}

# only need to worry if a partition is mounted
# just pass through internal disks although they never show up
# anyways
if (!$cce->event_is_destroy() && $disk->{mounted} && !$disk->{internal})
{
    # add the new link
    if (not Sauce::Util::linkfile($disk->{mountPoint}, $new_link))
    {
        $cce->warn('[[base-storage.changeLabelFailed]]');
        $cce->bye('FAIL');
        exit(1);
    }
}

$cce->bye('SUCCESS');
exit(0);
