#!/usr/bin/perl -w -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/storage
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
# $Id: setup_web_access.pl,v 1.2 2001/10/16 17:19:16 pbaltz Exp $
#
# make sure that additional storage setup as a directory for sites
# is added to the access configuration file, so that user's web pages
# are accessible

use CCE;
use Sauce::Service;
use Base::Httpd qw(httpd_set_access_rules);
use Storage qw(storage_get_mount_point);

my $cce = new CCE('Domain' => 'base-storage');
$cce->connectfd();

my $disk = $cce->event_object();
my $new_disk = $cce->event_new();

if ($cce->event_is_destroy())
{
    $disk = $cce->event_old();
}

# don't bother if the disk is internal
if ($disk->{internal})
{
    $cce->bye('SUCCESS');
    exit(0);
}

# check for whether the sections should be removed or added
my $remove = 0;
if ($cce->event_is_destroy() || !$disk->{isHomePartition} || 
    (exists($new_disk->{mount}) && !$new_disk->{mount}))
{
    $remove = 1;
}

# modify the section for the .sites directory
my $info = {
            'Options' => [ 
                            'Indexes', 'FollowSymLinks', 
                            'Includes', 'MultiViews'
                            ],
            'AllowOverride' => [ 'AuthConfig', 'Indexes', 'Limit' ],
            'FileSections' => { '.ht*' => { 'deny' => [ 'all' ] } },
            'order' => [ 'allow', 'deny' ],
            'allow' => [ 'all' ]
            };

my $dir = storage_get_mount_point($disk) . '/.sites/';
if (!httpd_set_access_rules('Directory', $dir, ($remove ? '' : $info)))
{
    $cce->bye('FAIL', 'cantSetupApacheConfig');
    exit(1);
}

# modify section for individual sites
$info = { 'Options' => [ '-FollowSymLinks', '+SymLinksIfOwnerMatch' ] };
$dir .= '*/*/';

if (!httpd_set_access_rules('Directory', $dir, ($remove ? '' : $info)))
{
    $cce->bye('FAIL', 'cantSetupApacheConfig');
    exit(1);
}

# restart the public server
service_run_init('httpd', 'reload');

$cce->bye('SUCCESS');
exit(0);
