#!/usr/bin/perl -w -I /usr/sausalito/perl -I /usr/sausalito/handlers/base/storage
# $Id: touch_flag.pl,v 1.3 2001/10/24 18:12:57 will Exp $
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
#
# touch the marker on a disk when it is setup

use CCE;
use Sauce::Util;
use Base::Disk qw(disk_getmounts);
use Storage qw(storage_mount storage_umount);

my $DEBUG = 0;

my $cce = new CCE('Domain' => 'base-storage');
$cce->connectfd();

my $disk = $cce->event_object();

# don't worry if no fsType or it is a cd (read-only) or if internal
if (!$disk->{fsType} || $disk->{fsType} =~ /^iso9660$/ || $disk->{internal})
{
    $cce->bye('SUCCESS');
    exit(0);
}

my $mounts = disk_getmounts();
my $mounted = 0;

if (!$mounts->{$disk->{device}})
{
    my $disk_stats = storage_mount($disk, 'nocheck');
    if (!defined($disk_stats))
    {
        $DEBUG && warn("couldn't mount $disk->{device}");
        $cce->bye('FAIL', 'cantTouchFlag', { 'device' => $disk->{device} });
        exit(1);
    }

    $disk->{mountPoint} = $disk_stats->{MountPoint};
    $mounted = 1;
}

if (!$disk->{new})
{
    # touch the file that indicates we've seen this disk
    if (!Sauce::Util::editfile("$disk->{mountPoint}/.cobalt_storage",   
                                *touch_flag))
    {
        $DEBUG && warn("couldn't edit file $disk->{mountPoint}/.cobalt_storage");
        $cce->bye('FAIL', 'cantTouchFlag', { 'device' => $disk->{device} });
        exit(1);
    }
}
else
{
    Sauce::Util::unlinkfile("$disk->{mountPoint}/.cobalt_storage");
}

if ($mounted)
{
    storage_umount($disk->{device});
}

$cce->bye('SUCCESS');
exit(0);

sub touch_flag
{
    my ($in, $out) = @_;
    
    print $out "Do not remove this file.  It is a marker to indicate this ";
    print $out "has been setup.\n";

    return 1;
}
